import { dirname, resolve, join } from "path";
import pkg from "fs-extra";
import { fileURLToPath } from "url";
import { appIndexTsTemplate } from "./templates/src/ui/index.tsx.template.js";
import { appTemplate } from "./templates/src/ui/App.tsx.template.js";
import { indexCssTemplate } from "./templates/src/ui/index.css.template.js";
import { trpcClientTemplate } from "./templates/src/ui/trpc.ts.template.js";
import { siteConfigurationSurfaceTemplate, siteConfigurationSurfaceWithSafeguardTemplate, } from "./templates/src/ui/surfaces/SiteConfiguration.tsx.template.js";
import { trpcFunctionTemplate } from "./templates/src/endpoints/trpc.ts.template.js";
import { trpcServerRouterTemplate } from "./templates/src/server/router.ts.template.js";
import { serverTrpcTemplate } from "./templates/src/server/trpc.ts.template.js";
import { indexHtmlTemplate } from "./templates/src/ui/index.html.js";
import { tailwindConfigTsTemplate } from "./templates/tailwind.config.ts.template.js";
import { tsconfigBackendJsonTemplate, tsconfigJsonTemplate, tsconfigUiJsonTemplate, } from "./templates/tsconfig.json.template.js";
import { viteConfigTemplate } from "./templates/vite.config.ts.template.js";
import { netlifyTomlTemplate } from "./templates/netlify.toml.template.js";
import { teamConfigurationSurfaceTemplate } from "./templates/src/ui/surfaces/TeamConfiguration.tsx.template.js";
import { BOILERPLATE_OPTIONS } from "../constants.js";
import { connectConfigurationSurfaceTemplate } from "./templates/src/ui/surfaces/ConnectConfiguration.tsx.template.js";
import { TeamConfigurationSchemaTemplate } from "./templates/src/schema/team-configuration.ts.template.js";
import { visualEditorConfigurationSurfaceTemplate } from "./templates/src/ui/surfaces/VisualEditorConfiguration.tsx.template.js";
import { ConnectorSchemaTemplate } from "./templates/src/schema/connector-configuration.ts.template.js";
import { imagesTypeTemplate } from "./templates/src/types/images.ts.template.js";
import { copyDirectory } from "../utils.js";
const { ensureDirSync, writeFileSync } = pkg;
export const extensionUIDeps = [
    "@netlify/functions@latest",
    "@netlify/sdk@latest",
    "react@latest",
    "react-dom@latest",
    "@trpc/client@11.0.0-rc.477", // todo: make sure we are using the same version as @netlify/sdk--ui-functions (preferably the latest supported version)
    "@trpc/server@11.0.0-rc.477", // ! should be same version as `@trpc/client` and `@trpc/react-query`
    "@trpc/react-query@11.0.0-rc.477", // ! should be same version as `@trpc/client` and `@trpc/react-query`
    "@tanstack/react-query@latest",
    "zod@latest",
];
export const extensionUIDevDeps = [
    "@types/react@latest",
    "@types/react-dom@latest",
    "@tsconfig/node18@latest",
    "@tsconfig/recommended@latest",
    "@tsconfig/strictest@latest",
    "@tsconfig/vite-react@latest",
    "@vitejs/plugin-react@latest",
    "vite@latest",
    "autoprefixer@latest",
    "tailwindcss@^3.4.3",
    "netlify-cli@latest",
];
export const generateUiBoilerplate = (destination, boilerplate, connectorSupports, safeGuardEnvVar) => {
    const hasBuildEventHandler = boilerplate.includes(BOILERPLATE_OPTIONS.build);
    const hasConnectorBoilerplate = boilerplate.includes(BOILERPLATE_OPTIONS.connector);
    const hasUIBoilerplate = boilerplate.includes(BOILERPLATE_OPTIONS.ui);
    const files = {
        "netlify.toml": netlifyTomlTemplate,
        "src/ui/index.html": indexHtmlTemplate,
        "src/ui/index.tsx": appIndexTsTemplate,
        "src/ui/App.tsx": appTemplate(boilerplate, connectorSupports),
        "src/ui/index.css": indexCssTemplate,
        "src/ui/trpc.ts": trpcClientTemplate,
        "src/endpoints/trpc.ts": trpcFunctionTemplate,
        "src/server/trpc.ts": serverTrpcTemplate,
        "src/server/router.ts": trpcServerRouterTemplate(hasBuildEventHandler, safeGuardEnvVar, hasConnectorBoilerplate),
        "src/schema/team-configuration.ts": TeamConfigurationSchemaTemplate,
        "src/types/images.d.ts": imagesTypeTemplate,
        "tailwind.config.ts": tailwindConfigTsTemplate,
        "tsconfig.json": tsconfigJsonTemplate,
        "tsconfig.ui.json": tsconfigUiJsonTemplate,
        "tsconfig.backend.json": tsconfigBackendJsonTemplate,
        "vite.config.ts": viteConfigTemplate,
    };
    if (hasUIBoilerplate) {
        files["src/ui/surfaces/SiteConfiguration.tsx"] = hasBuildEventHandler
            ? siteConfigurationSurfaceWithSafeguardTemplate
            : siteConfigurationSurfaceTemplate;
        files["src/ui/surfaces/TeamConfiguration.tsx"] =
            teamConfigurationSurfaceTemplate;
    }
    if (hasConnectorBoilerplate) {
        files["src/schema/connector-configuration.ts"] = ConnectorSchemaTemplate;
        if (connectorSupports.connect) {
            files["src/ui/surfaces/ConnectConfiguration.tsx"] =
                connectConfigurationSurfaceTemplate;
        }
        if (connectorSupports.visualEditor) {
            files["src/ui/surfaces/VisualEditorConfiguration.tsx"] =
                visualEditorConfigurationSurfaceTemplate;
        }
    }
    for (const [file, content] of Object.entries(files)) {
        const dir = dirname(resolve(destination, file));
        ensureDirSync(resolve(destination, dir));
        writeFileSync(resolve(destination, file), content);
    }
    // Get assets folder and copy to destination
    const __dirname = dirname(fileURLToPath(import.meta.url));
    const srcDir = join(__dirname, "/templates/src/assets");
    const destDir = join(destination, "/src/assets/");
    copyDirectory(srcDir, destDir);
};
//# sourceMappingURL=generate-ui-boilerplate.js.map